@@ -7,10 +7,17 @@ import json
 from pathlib import Path
 from typing import Dict, Any, Optional, List
 
-from ..base import (
-    Plugin, PluginMetadata, PluginCapability,
-    ActionResult
-)
+try:
+    from ..base import (
+        Plugin, PluginMetadata, PluginCapability,
+        ActionResult
+    )
+except ImportError:
+    # When loaded dynamically via importlib
+    from nc1709.plugins.base import (
+        Plugin, PluginMetadata, PluginCapability,
+        ActionResult
+    )
 
 
 class NextJSAgent(Plugin):
