@@ -9,12 +9,22 @@ from pathlib import Path
 from typing import Dict, Any, Optional, List
 from datetime import datetime
 
-from fastapi import FastAPI, HTTPException, WebSocket, WebSocketDisconnect, Header, Depends
+from fastapi import FastAPI, HTTPException, WebSocket, WebSocketDisconnect, Header, Depends, Request
 from fastapi.staticfiles import StaticFiles
 from fastapi.responses import HTMLResponse, FileResponse
 from fastapi.middleware.cors import CORSMiddleware
 from pydantic import BaseModel
 
+# Import conversation logger
+try:
+    from ..conversation_logger import ConversationLogger
+    HAS_CONVERSATION_LOGGER = True
+except ImportError:
+    HAS_CONVERSATION_LOGGER = False
+
+# Session loggers by client IP
+_session_loggers: Dict[str, ConversationLogger] = {}
+
 # Get the directory where this file is located
 WEB_DIR = Path(__file__).parent
 STATIC_DIR = WEB_DIR / "static"
@@ -543,11 +553,32 @@ def create_app() -> FastAPI:
     @app.get("/api/remote/status")
     async def remote_status(authorized: bool = Depends(verify_api_key)):
         """Check remote API status and available models"""
+        from .. import __version__
         config = get_config()
+
+        # Count available tools (tools that client can execute locally)
+        tools_count = 17  # Default count
+        try:
+            from ..agent.tools.base import ToolRegistry
+            from ..agent.tools.file_tools import register_file_tools
+            from ..agent.tools.search_tools import register_search_tools
+            from ..agent.tools.bash_tool import register_bash_tools
+            from ..agent.tools.web_tools import register_web_tools
+
+            registry = ToolRegistry()
+            register_file_tools(registry)
+            register_search_tools(registry)
+            register_bash_tools(registry)
+            register_web_tools(registry)
+            tools_count = len(registry.list_names())
+        except ImportError:
+            pass
+
         return {
             "status": "ok",
             "server": "nc1709",
-            "version": "1.4.0",
+            "version": __version__,
+            "tools_count": tools_count,
             "models": config.get("models", {}),
             "ollama_url": config.get("ollama.base_url", "http://localhost:11434"),
             "auth_required": bool(config.get("remote.api_key")),
@@ -760,6 +791,7 @@ def create_app() -> FastAPI:
     @app.post("/api/remote/agent")
     async def remote_agent_chat(
         request: AgentChatRequest,
+        http_request: Request,
         authorized: bool = Depends(verify_api_key)
     ):
         """
@@ -772,6 +804,26 @@ def create_app() -> FastAPI:
         4. Client parses tool calls and executes them LOCALLY
         5. Client sends tool results back for next iteration
         """
+        # Get client IP for logging
+        client_ip = http_request.client.host if http_request.client else "unknown"
+        user_agent = http_request.headers.get("user-agent", "unknown")
+
+        # Get or create logger for this client
+        if HAS_CONVERSATION_LOGGER:
+            if client_ip not in _session_loggers:
+                _session_loggers[client_ip] = ConversationLogger(
+                    ip_address=client_ip,
+                    user_agent=user_agent,
+                    mode="server"
+                )
+            logger = _session_loggers[client_ip]
+
+            # Log the last user message if present
+            if request.messages:
+                last_msg = request.messages[-1]
+                if last_msg.get("role") == "user":
+                    logger.log_user_message(last_msg.get("content", ""), {"cwd": request.cwd})
+
         try:
             from ..llm_adapter import LLMAdapter
             from ..prompts.unified_prompt import get_unified_prompt
@@ -788,12 +840,19 @@ def create_app() -> FastAPI:
             # Get LLM response (just thinking, no execution)
             response = llm.chat(messages)
 
+            # Log assistant response
+            if HAS_CONVERSATION_LOGGER and client_ip in _session_loggers:
+                _session_loggers[client_ip].log_assistant_message(response[:2000])
+
             return {
                 "response": response,
                 "timestamp": datetime.now().isoformat(),
                 "type": "agent_response"
             }
         except Exception as e:
+            # Log error
+            if HAS_CONVERSATION_LOGGER and client_ip in _session_loggers:
+                _session_loggers[client_ip].log_error(str(e))
             raise HTTPException(status_code=500, detail=str(e))
 
     # =========================================================================
